drawing_bullets.pdf

## Metadata

Title | drawing_bullets.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\drawing_bullets.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403061521+01'00'
PDF Metadata: modDate | D:20230403061521+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 521.47412109375
y1 |  | 140.3957977294922
y0 |  | 121.07579803466797
x0 |  | 72.26399993896484

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 526.5550537109375
y1 |  | 195.83580017089844
y0 |  | 155.7557830810547
x0 |  | 72.26399993896484

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 515.7210083007812
y1 |  | 230.5157928466797
y0 |  | 211.19578552246094
x0 |  | 72.26399993896484

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 517.5850830078125
y1 |  | 265.22576904296875
y0 |  | 245.9058074951172
x0 |  | 72.26399993896484

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 533.8599853515625
y1 |  | 392.9377136230469
y0 |  | 367.1377258300781
x0 |  | 74.18399810791016

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 528.7319946289062
y1 |  | 475.8777160644531
y0 |  | 408.677734375
x0 |  | 74.18399810791016

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 523.6799926757812
y1 |  | 517.5177001953125
y0 |  | 491.71771240234375
x0 |  | 74.18399810791016

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 519.1441040039062
y1 |  | 572.86767578125
y0 |  | 533.2376708984375
x0 |  | 74.18399810791016

Lorem ipsum dolor sit amet. Ut voluptas quaerat qui aliquid consectetur in sapiente cupiditate ut dolorem cumque ut placeat atque. Et dolorem similique ut soluta ipsam est aspernatur vero?

Sit quibusdam illo est eius veniam est explicabo laudantium ut nihil tempora et tempora vitae et enim suscipit qui libero dolores? Id ullam voluptatibus qui pariatur impedit sit sint dolor ut quod quibusdam qui dolorum velit qui fuga impedit qui veniam soluta? Ut rerum accusantium quo vero doloremque sed dicta molestiae et velit beatae in debitis nihil 33 eius quis qui architecto enim.

In explicabo sint aut nobis quia qui nihil nihil non magnam deleniti. Ea quae praesentium aut doloremque deserunt sit quia sequi!

Non tempore quia et consequatur dolorem qui asperiores quidem qui iste esse est deleniti cumque est amet minima et dolor quis! Sit quia natus qui earum harum ut modi dolorem qui consequatur provident et sint ipsam.

Lorem ipsum dolor sit amet. Ut voluptas quaerat qui aliquid consectetur in sapiente cupiditate ut dolorem cumque ut placeat atque. Et dolorem similique ut soluta ipsam est aspernatur vero?

Sit quibusdam illo est eius veniam est explicabo laudantium ut nihil tempora et tempora vitae et enim suscipit qui libero dolores? Id ullam voluptatibus qui pariatur impedit sit sint dolor ut quod quibusdam qui dolorum velit qui fuga impedit qui veniam soluta? Ut rerum accusantium quo vero doloremque sed dicta molestiae et velit beatae in debitis nihil 33 eius quis qui architecto enim.

In explicabo sint aut nobis quia qui nihil nihil non magnam deleniti. Ea quae praesentium aut doloremque deserunt sit quia sequi!

Non tempore quia et consequatur dolorem qui asperiores quidem qui iste esse est deleniti cumque est amet minima et dolor quis! Sit quia natus qui earum harum ut modi dolorem qui consequatur provident et sint ipsam.

Lorem ipsum dolor sit amet. Ut voluptas quaerat qui aliquid consectetur in sapiente cupiditate ut dolorem cumque ut placeat atque. Et dolorem similique ut soluta ipsam est aspernatur vero?

Sit quibusdam illo est eius veniam est explicabo laudantium ut nihil tempora et tempora vitae et enim suscipit qui libero dolores? Id ullam voluptatibus qui pariatur impedit sit sint dolor ut quod quibusdam qui dolorum velit qui fuga impedit qui veniam soluta? Ut rerum accusantium quo vero doloremque sed dicta molestiae et velit beatae in debitis nihil 33 eius quis qui architecto enim.

In explicabo sint aut nobis quia qui nihil nihil non magnam deleniti. Ea quae praesentium aut doloremque deserunt sit quia sequi!

Non tempore quia et consequatur dolorem qui asperiores quidem qui iste esse est deleniti cumque est amet minima et dolor quis! Sit quia natus qui earum harum ut modi dolorem qui consequatur provident et sint ipsam.

Lorem ipsum dolor sit amet. Ut voluptas quaerat qui aliquid consectetur in sapiente cupiditate ut dolorem cumque ut placeat atque. Et dolorem similique ut soluta ipsam est aspernatur vero?

Sit quibusdam illo est eius veniam est explicabo laudantium ut nihil tempora et tempora vitae et enim suscipit qui libero dolores? Id ullam voluptatibus qui pariatur impedit sit sint dolor ut quod quibusdam qui dolorum velit qui fuga impedit qui veniam soluta? Ut rerum accusantium quo vero doloremque sed dicta molestiae et velit beatae in debitis nihil 33 eius quis qui architecto enim.

In explicabo sint aut nobis quia qui nihil nihil non magnam deleniti. Ea quae praesentium aut doloremque deserunt sit quia sequi!

Non tempore quia et consequatur dolorem qui asperiores quidem qui iste esse est deleniti cumque est amet minima et dolor quis! Sit quia natus qui earum harum ut modi dolorem qui consequatur provident et sint ipsam.

Parent File Contents